==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/ctimerlist.h <==
/***************************************************************************
                          ctimerlist.h  -  description
                             -------------------
    begin                : ?t mj 8 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTIMERLIST_H
#define CTIMERLIST_H

#include <qwidget.h>
#include "csaveablelist.h"
#include "ctimertick.h"

class cSession;
class dlgTimers;
class QTimer;

/**
List of timers.
  *@author Tomas Mecir
  */

class cTimerList : public cSaveableList  {
   Q_OBJECT
public:
  cTimerList (QString filename, cSession *_sess);
  ~cTimerList ();
  void setDialog (dlgTimers *dlg) { dialog = dlg; };
  cTimerTick* getTimerTick() { return timerTick; }

public slots:
  void enableTimers ();
  void disableTimers ();
protected slots:
  void timeout ();
protected:
  /** function not valid here, so it's overriden to prevent problems */
  void setEnabled (bool) {};
  /** abstract & not needed*/
  virtual void processCommands (const QStringList &) {};
  int tickCount;
  dlgTimers *dialog;
  QTimer *timer;
  cTimerTick *timerTick;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/ctimerlist.h <==
/***************************************************************************
                          ctimerlist.h  -  list of timers
                             -------------------
    begin                : St maj 8 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTIMERLIST_H
#define CTIMERLIST_H

#include <qwidget.h>
#include "csaveablelist.h"

class cTimerTick;
class dlgTimers;
class QTimer;

/**
List of timers.
  *@author Tomas Mecir
  */

class cTimerList : public cSaveableList  {
   Q_OBJECT
public:
  cTimerList (QString filename, int sess);
  ~cTimerList ();
  void setDialog (dlgTimers *dlg) { dialog = dlg; };
  cTimerTick* getTimerTick() { return timerTick; }

public slots:
  void enableTimers ();
  void disableTimers ();
protected slots:
  void timeout ();
protected:
  /** function not valid here, so it's overriden to prevent problems */
  void setEnabled (bool) {};
  /** abstract & not needed*/
  virtual void processCommands (const QStringList &) {};
  int tickCount;
  dlgTimers *dialog;
  QTimer *timer;
  cTimerTick *timerTick;
};

#endif
